@@ -31,6 +31,7 @@ second = 1
 second = ""
 class TestClass(object):
     var_class = TestClass(1)
+    self.pseudo_var = 3
 
     def __init__(self2, first_param, second_param, third=1.0):
         self2.var_inst = first_param
@@ -85,6 +86,10 @@ TestClass.var
 inst.var_local
 #? []
 TestClass.var_local.
+#?
+TestClass.pseudo_var
+#?
+TestClass().pseudo_var
 
 #? int()
 TestClass().ret(1)
@@ -279,7 +284,7 @@ V(1).c()
 V(1).d()
 # Only keywords should be possible to complete.
 #? ['is', 'in', 'not', 'and', 'or', 'if']
-V(1).d()
+V(1).d() 
 
 
 # -----------------
@@ -377,6 +382,7 @@ getattr(getattr, 1)
 getattr(str, [])
 
 
+# python >= 3.5
 class Base():
     def ret(self, b):
         return b
@@ -394,6 +400,12 @@ class Wrapper2():
 
 #? int()
 Wrapper(Base()).ret(3)
+#? ['ret']
+Wrapper(Base()).ret
+#? int()
+Wrapper(Wrapper(Base())).ret(3)
+#? ['ret']
+Wrapper(Wrapper(Base())).ret
 
 #? int()
 Wrapper2(Base()).ret(3)
@@ -404,6 +416,8 @@ class GetattrArray():
 
 #? int()
 GetattrArray().something[0]
+#? []
+GetattrArray().something
 
 
 # -----------------
@@ -602,3 +616,17 @@ DefaultArg().y()
 DefaultArg.x()
 #? str()
 DefaultArg.y()
+
+
+# -----------------
+# Error Recovery
+# -----------------
+
+from import_tree.pkg.base import MyBase
+
+class C1(MyBase):
+    def f3(self):
+        #! 13 ['def f1']
+        self.f1() . # hey'''
+        #? 13 MyBase.f1
+        self.f1() . # hey'''
