@@ -1,3 +1,18 @@
+# -*- coding: utf-8 -*-
+import warnings
+
+import pytest
+
+from jedi._compatibility import u
+
+
+@pytest.fixture(autouse=True)
+def check_for_warning(recwarn):
+    warnings.simplefilter("always")
+    with pytest.warns(DeprecationWarning):
+        yield
+
+
 def test_goto_definitions(Script):
     int_, = Script('x = 1\nx, y\ny', line=2, column=0).goto_definitions()
     assert int_.name == 'int'
@@ -25,3 +40,9 @@ def test_usages(Script):
 def test_call_signatures(Script):
     d1, = Script('abs(float(\nstr(', line=1, column=4).call_signatures()
     assert d1.name == 'abs'
+
+
+def test_encoding_parameter(Script):
+    name = u('hö')
+    s = Script(name.encode('latin-1'), encoding='latin-1')
+    assert s._module_node.get_code() == name
